Module allocator

Module allocator 

Allocator - Memory Allocation Traits and Implementations

File

crates/axonml-core/src/allocator.rs

Author

Andrew Jewell Sr - AutomataNexus

Updated

March 8, 2026

Disclaimer

Use at own risk. This software is provided “as is”, without warranty of any kind, express or implied. The author and AutomataNexus shall not be held liable for any damages arising from the use of this software.

Structs

DefaultAllocator
Default CPU allocator using system memory.

Traits

Allocator
Marker trait for types that can act as allocators.